#
# Makefile Template for Tessy
# Compiler: ARM RVDS
# Debugger: Keil Vision
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# ALIGN_COMM_BUFFER     :=
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# SCATTER_FILE          :=
# STARTUP_FILE          :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
ARM_HOME        := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
ARM_DLLS        := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)/../LIB')
ARM_HEADER      := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)/../RV31/INC')
ARM_INC         := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)/../INC/ST')

UVSC_HOME       := $(shell ts_pathname -s '$(TARGET_INSTALL_PATH)')

ifneq ($(InitSrcDir),)
INITOBJDIR      := $(shell cygpath -m $(InitObjDir))
INITSRCDIR      := $(shell cygpath -m $(InitSrcDir))
endif

ifeq ($(ALIGN_COMM_BUFFER),)
ALIGN_COMM_BUFFER := 0
endif

# for older versions of the compiler (before 4.0), use --device option
#CPU_OPT         := --device DARMP1
CPU_OPT			 := --cpu $(CPU)

TS_NAME         := TS_UVISION
IDE_NAME        := uvision_uvsc
COMPANY_NAME    := keil
PROCESSOR_NAME  := arm_rvds

all    : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)


#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := $(CPU_OPT) -g -O0 -DSTM32F10X_MD --apcs=interwork -I $(ARM_INC) -I$(PROJECTROOT)\tessy\config\InitSrcDir \
                  -I $(ARM_HEADER) -DTESSY -DTS_SLAVE -DTS_RVDS_ARM -DTS_ARM -DTS_HAVE_FLOAT64 \
                  -DTS_ALIGN_BUFFER=$(ALIGN_COMM_BUFFER) -DTS_HAVE___int64 -D__MICROLIB
S_LINK_OPTIONS := --library_type=microlib $(CPU_OPT) --strict --scatter $(SCATTER_FILE) --autoat --libpath $(ARM_DLLS)
S_INCLUDES     := -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)

S_CC           := $(ARM_HOME)\armcc.exe
S_ASM          := $(ARM_HOME)\armasm.exe
S_LINK         := $(ARM_HOME)\armlink.exe
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)



#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -o $@ -c "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


#
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	@echo ***** Compiling Usercode *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	@echo ***** Compiling Stubs *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)



#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -o $@ -c $<

ifeq ("true","$(USE_BOARD_FILES)")
ARM_RVDS_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
                 $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) $(S_COMP_OPTIONS) -I"$(INITOBJDIR)" $(S_INCLUDES) -o $@ -c $<

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_CC) $(S_COMP_OPTIONS) -I"$(INITOBJDIR)" $(S_INCLUDES) -o $@ -c $<
endif

$(MODULE_PATH_DOS)\Startup$(OBJFILE_EXTENSION): $(STARTUP_FILE)
	$(S_ASM) $(CPU_OPT) -g --apcs=interwork --pd "__MICROLIB SETA 1" -I $(ARM_INC) -o "$@" "$<"

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
									$(S_SRC_OBJECTS) \
									$(ARM_RVDS_OBJS) \
									$(S_UC_OBJECT) \
									$(S_STUB_OBJECT) \
									$(S_OBJECTS) \
									$(MODULE_PATH_DOS)\Startup$(OBJFILE_EXTENSION)

	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) --output $@ $(ARM_RVDS_OBJS) \
		$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) $(S_SRC_OBJECTS) \
		$(S_UC_OBJECT) $(S_STUB_OBJECT) $(S_OBJECTS) \
		$(MODULE_PATH_DOS)\Startup$(OBJFILE_EXTENSION)
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)


#####################################################################
#END_TARGETS
#####################################################################












